package com.hbq.update;

import android.app.ActivityManager;
import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;
import android.telephony.TelephonyManager;
import android.util.Log;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.LineNumberReader;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.util.Enumeration;
import java.util.List;
import org.apache.http.conn.util.InetAddressUtils;

/**
 * 方法
 */
public class SystemUtils {

	private static final String TAG = "SystemUtils";

	private static Context context = null;

	public static void setContext(Context cont) {
		context = cont;
	}

	public static Context getContext() {
		return context;
	}

	/**
	 * 判断应用是否已经启动
	 * 
	 * @param context
	 *            一个context
	 * @param packageName
	 *            要判断应用的包名
	 * @return boolean
	 */
	public static boolean isAppAlive(Context context, String packageName) {
		ActivityManager activityManager = (ActivityManager) context
				.getSystemService(Context.ACTIVITY_SERVICE);
		List<ActivityManager.RunningAppProcessInfo> processInfos = activityManager
				.getRunningAppProcesses();
		for (int i = 0; i < processInfos.size(); i++) {
			if (processInfos.get(i).processName.equals(packageName)) {
				return true;
			}
		}
		return false;
	}

	/**
	 * 获取配置属性
	 * */
	public static String getPropertiesByKey(String key) {
		Bundle metaData = null;
		String value = null;
		try {
			if(context==null) return value;
			ApplicationInfo ai = context.getPackageManager()
					.getApplicationInfo(context.getPackageName(),
							PackageManager.GET_META_DATA);
			if (null != ai)
				metaData = ai.metaData;
			if (null != metaData) {
				value = metaData.get(key).toString();
			}
		} catch (PackageManager.NameNotFoundException e) {
			Log.e(TAG, "NameNotFoundException", e);
		}
		return value;
	}

	/**
	 * *是否有网
	 * */
	public static boolean isOpenNetwork() {
		ConnectivityManager connManager = (ConnectivityManager) context
				.getSystemService(Context.CONNECTIVITY_SERVICE);
		NetworkInfo info = connManager.getActiveNetworkInfo();
		if (null != info && info.isAvailable()) {
			return true;
		}
		Log.e(TAG, "Network is wrong.");
		return false;
	}

	/**
	 * 服务是否开启
	 * **/
	public static boolean isServiceRunning() {
		ActivityManager manager = (ActivityManager) context
				.getSystemService(Context.ACTIVITY_SERVICE);
		for (ActivityManager.RunningServiceInfo service : manager
				.getRunningServices(Integer.MAX_VALUE)) {
			if ("org.egret.java.AAA.PushService".equals(service.service
					.getClassName())) {
				Log.d(TAG, "service is running.");
				return true;
			}
		}
		Log.e(TAG, "service is not running.");
		return false;
	}

	// 是否安装微信
	public static boolean isWeixinAvilible() {
		final PackageManager packageManager = context.getPackageManager();// 获取packagemanager
		List<PackageInfo> pinfo = packageManager.getInstalledPackages(0);// 获取所有已安装程序的包信息
		if (pinfo != null) {
			for (int i = 0; i < pinfo.size(); i++) {
				String pn = pinfo.get(i).packageName;
				if (pn.equals("com.tencent.mm")) {
					return true;
				}
			}
		}
		return false;
	}

	/*
	 * 获取本机ip
	 */
	public static String getLocalHostIp() {
		try {
			Enumeration<NetworkInterface> en = NetworkInterface
					.getNetworkInterfaces();
			while (en.hasMoreElements()) {
				NetworkInterface networkInterface = (NetworkInterface) en
						.nextElement();
				Enumeration<InetAddress> inet = networkInterface
						.getInetAddresses();
				while (inet.hasMoreElements()) {
					InetAddress inetAddress = (InetAddress) inet.nextElement();
					if (!inetAddress.isLoopbackAddress()
							&& InetAddressUtils.isIPv4Address(inetAddress
									.getHostAddress())) {
						Log.e(TAG, "本机ip是 ： " + inetAddress.getHostAddress());
						return inetAddress.getHostAddress();
					}
				}
			}
		} catch (SocketException e) {
			// TODO Auto-generated catch block
			Log.e(TAG, "获取ip失败");
			e.printStackTrace();
		}
		return "";
	}

	/*
	 * 获取imei
	 */
	public static String getDeviceId() {
		TelephonyManager tm = (TelephonyManager) context
				.getSystemService(Context.TELEPHONY_SERVICE);
		return tm.getDeviceId();
	}

	public static String getDeciveBuild() {
		return android.os.Build.BRAND + android.os.Build.MODEL;
	}

	public static String getMac() {
		String macSerial = null;
		String str = "";
		try {
			Process pp = Runtime.getRuntime().exec(
					"cat /sys/class/net/wlan0/address ");
			InputStreamReader ir = new InputStreamReader(pp.getInputStream());
			LineNumberReader input = new LineNumberReader(ir);
			for (; null != str;) {
				str = input.readLine();
				if (str != null) {
					macSerial = str.trim();// 去空格
					break;
				}
			}
		} catch (IOException ex) {
			// 赋予默认值
			ex.printStackTrace();
		}
		return macSerial;
	}

	/**
	 * 获取当前版本名称
	 * @param ctx
	 * @return
	 */
	public static String getVersionName(Context ctx) {
		try {
			PackageManager manager = ctx.getPackageManager();
			PackageInfo info = manager.getPackageInfo(ctx.getPackageName(), 0);
			String version = info.versionName;
			return  version;
		} catch (Exception e) {
			e.printStackTrace();
			return "";
		}
	}
	
	/**
	 * 获取当前版本号
	 * @param ctx
	 * @return
	 */
	public static int getVersionCode(Context ctx) {
		try {
			PackageManager manager = ctx.getPackageManager();
			PackageInfo info = manager.getPackageInfo(ctx.getPackageName(), 0);
			int version = info.versionCode;
			Log.d(TAG,version+"");
			return  version;
		} catch (Exception e) {
			e.printStackTrace();
			return 0;
		}
	}

}

