package com.hbq.update;

import android.text.TextUtils;
import android.util.Log;
import android.widget.Toast;
import java.io.File;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReadableArray;
import org.json.JSONObject;
import org.json.JSONException;
import android.os.Handler;
import android.app.ProgressDialog;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import android.net.Uri;
import android.os.Environment;
import android.os.Message;
import android.annotation.SuppressLint;
import com.facebook.react.modules.core.DeviceEventManagerModule;
public class UpdateAndroidModule extends ReactContextBaseJavaModule{

    private static final int SDK_PAY_FLAG = 1;
    private static final String TAG = "UpdateAndroidModule";
    ProgressDialog _progressDlg;
    Dialog dialog;
    String _appNameStr;
    String _appDownUrl;

    @SuppressLint("HandlerLeak")
    private Handler _mainHandler = new Handler(getReactApplicationContext().getMainLooper()) {
        @SuppressWarnings("unused")
        public void handleMessage(Message msg) {
            Log.d(TAG,msg.what+"");
            try{
                switch (msg.what) {
                    case SDK_PAY_FLAG: {
                        initDialog();
                        break;
                    }
                    default:
                        break;
                }
            }catch (Exception e){
                Log.d(TAG, "error: " + e.toString());
            }
        };
    };

    public UpdateAndroidModule(ReactApplicationContext reactContext) {
        super(reactContext);
    }

    @Override
    public String getName() {
        return "UpdateAndroidModule";
    }

    @ReactMethod
    public void startUpdate(){
        new Thread(new Runnable() {
            @Override
            public void run() {
                SystemUtils.setContext(getCurrentActivity());
                String package_config = SystemUtils.getPropertiesByKey("PACKAGE_CONFIG")+ "?v=" + System.currentTimeMillis()/1000;
                Log.d(TAG, "http 请求数据"+package_config);
                JSONObject msg = Constants.httpRequest(package_config);
                Log.d(TAG, "http 请求数据" + msg);
                if(msg != null) setValues(msg);
            }
        }).start();
    }
    
    private void setValues(JSONObject msg) {
        try {
            int curVersionCode = SystemUtils.getVersionCode(getCurrentActivity());
            String curVersionName = SystemUtils.getVersionName(getCurrentActivity());
            /******版本检测******/
            JSONObject versionObj= msg.optJSONObject("androidVersion");
            Log.d(TAG,"当前版本："+curVersionCode);
            if(curVersionCode != 0 && versionObj != null){
                int newVersionCode=versionObj.optInt("versionCode");
                //String newVersionName = versionObj.optString("VersionName");
                if(curVersionCode<newVersionCode){
                    Log.d(TAG, "提示更新最新版本");
                    String appDownUrl=versionObj.getString("app_down_Url");
                    updateVersion(curVersionCode,newVersionCode,appDownUrl);
                    return;
                }else{
                    Log.d(TAG, "最新版本");
                }
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }
    
    private void updateVersion(int curVersion,int newVersion,String appDownUrl) {
        //开始更新
        _appDownUrl = appDownUrl;
        //发送消息到主线程更新进度条
        _mainHandler.sendEmptyMessage(SDK_PAY_FLAG);
    }
    
    private void showToast(String message) {
        Toast.makeText(getCurrentActivity(), message, Toast.LENGTH_SHORT).show();
    }

    //初始化进度条
    private void initDialog() {
        _progressDlg = new ProgressDialog(getCurrentActivity());
        _progressDlg.setProgressStyle(ProgressDialog.STYLE_HORIZONTAL);
        _progressDlg.setCanceledOnTouchOutside(false);
        _progressDlg.setIndeterminate(false);
        _appNameStr = "hbq.apk";
        _progressDlg.setCancelable(false);

        String str = "发现新版本,是否更新？";
        Dialog dialog = new AlertDialog.Builder(getCurrentActivity()).setTitle("软件更新").setMessage(str)
        .setNegativeButton("取消",new DialogInterface.OnClickListener(){
            @Override
            public void onClick(DialogInterface dialog, int which) {
                dialog.dismiss();
            }
        })
        .setPositiveButton("更新", new DialogInterface.OnClickListener(){
            @Override
            public void onClick(DialogInterface dialog, int which) {
                _progressDlg.setTitle("正在下载");
                _progressDlg.setMessage("请稍候...");
                downFile(_appDownUrl); // 开始下载
            }
        }).create();// 创建
        dialog.show();
        dialog.setCanceledOnTouchOutside(false);
    }

    private void downFile(final String url) {
        _progressDlg.show();
        new Thread() {
            public void run() {
                HttpClient client = new DefaultHttpClient();
                HttpGet get = new HttpGet(url);
                HttpResponse response;
                try {
                    response = client.execute(get);
                    HttpEntity entity = response.getEntity();
                    long length = entity.getContentLength();
                    _progressDlg.setMax((int) length / 1024);// 设置进度条的最大值
                    InputStream is = entity.getContent();
                    FileOutputStream fileOutputStream = null;
                    if (is != null) {
                        File file = new File(Environment.getExternalStorageDirectory(), _appNameStr);
                        fileOutputStream = new FileOutputStream(file);
                        byte[] buf = new byte[1024];
                        int ch = -1;
                        int count = 0;
                        while ((ch = is.read(buf)) != -1) {
                            fileOutputStream.write(buf, 0, ch);
                            count += ch;
                            if (length > 0) {
                                _progressDlg.setProgress(count / 1024);
                            }
                        }
                    }
                    fileOutputStream.flush();
                    if (fileOutputStream != null) {
                        fileOutputStream.close();
                    }
                    down();
                } catch (ClientProtocolException e) {
                    e.printStackTrace();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }.start();
    }

    private void down() {
        _mainHandler.post(new Runnable() {
            public void run() {
                _progressDlg.cancel();
                sendEvent("finishedAndroidUpdate", "success");
                update();
            }
        });
    }

    void update() {
        Intent intent = new Intent(Intent.ACTION_VIEW);
        intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK); 
        intent.setDataAndType(Uri.fromFile(new File(Environment.getExternalStorageDirectory(), _appNameStr)),
                "application/vnd.android.package-archive");
        getCurrentActivity().startActivity(intent);
        android.os.Process.killProcess(android.os.Process.myPid());
    }

    private void sendEvent(String eventName,String returnMsg){
        this.getReactApplicationContext()
            .getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter.class)
            .emit(eventName, returnMsg);
    }
}
